============
Installation
============

Get MongoDB::

    # TODO

Get the code::

    pip install django-mongonaut==0.2.5
    
Install the dependency in your settings.py::

    INSTALLED_APPS = (
    ...
    'mongonaut',
    ...
    )
    
You will need the following also set up:

* django.contrib.sessions
* django.contrib.messages